@@ -1,6 +1,5 @@
 // Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd
 // SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -8,6 +7,7 @@
 #include <QDir>
 #include <QLibraryInfo>
 #include <QJsonDocument>
+#include <QDebug>
 
 #include "eventlogutils.h"
 
@@ -15,9 +15,11 @@ EventLogUtils *EventLogUtils::mInstance(nullptr);
 
 EventLogUtils &EventLogUtils::get()
 {
+    // qDebug() << "Enter EventLogUtils::get()";
     if (mInstance == nullptr) {
         mInstance = new EventLogUtils;
     }
+    // qDebug() << "Exit EventLogUtils::get()";
     return *mInstance;
 }
 
@@ -28,17 +30,23 @@ EventLogUtils::EventLogUtils()
     init =reinterpret_cast<bool (*)(const std::string &, bool)>(library.resolve("Initialize"));
     writeEventLog = reinterpret_cast<void (*)(const std::string &)>(library.resolve("WriteEventLog"));
 
-    if (init == nullptr)
+    if (init == nullptr) {
+        qWarning() << "Failed to resolve Initialize function in libdeepin-event-log.so";
         return;
+    }
 
     init("deepin-terminal", true);
 }
 
 void EventLogUtils::writeLogs(QJsonObject &data)
 {
-    if (writeEventLog == nullptr)
+    // qDebug() << "Enter EventLogUtils::writeLogs()";
+    if (writeEventLog == nullptr) {
+        qWarning() << "writeEventLog function pointer is null";
         return;
+    }
 
     //std::string str = QJsonDocument(data).toJson(QJsonDocument::Compact).toStdString();
     writeEventLog(QJsonDocument(data).toJson(QJsonDocument::Compact).toStdString());
+    // qDebug() << "Exit EventLogUtils::writeLogs()";
 }
