@@ -1,5 +1,5 @@
-// Copyright (C) 2019 ~ 2023 Uniontech Software Technology Co.,Ltd
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -11,6 +11,9 @@
 
 #include <DPushButton>
 #include <DApplication>
+#ifdef DTKCORE_CLASS_DConfig
+#include <DConfig>
+#endif
 
 #include <QObject>
 #include <QHash>
@@ -20,6 +23,7 @@
 #include <QVariant>
 #include <QCommandLineParser>
 #include <QKeySequence>
+#include <QLoggingCategory>
 
 namespace Konsole {
 extern __attribute__((visibility("default"))) int __minFontSize;
@@ -415,7 +419,65 @@ public:
         }
         return nullptr;
     }
-    static FontDataList getFonts();
 };
 
+/*******************************************************************************
+ 1. @类名:    FontFilter
+ 2. @作者:    ut000610 daizhengwen
+ 3. @日期:    2020-08-11
+ 4. @说明:    打印DBUS获取等宽字体和比较字体字符方法获取等宽字体，用来定位DBUS获取字体失败后的问题
+*******************************************************************************/
+/******** Add by ut001000 renfeixiang 2020-06-15:增加 处理等宽字体的类 Begin***************/
+class FontFilter : public QObject
+{
+    Q_OBJECT
+public:
+    static FontFilter *instance();
+    FontFilter();
+    ~FontFilter();
+    //启动thread，打印等宽字体函数
+    /**
+     * @brief 启动thread，打印等宽字体函数
+     * @author ut001000 任飞翔
+     */
+    void handleWidthFont();
+    /**
+     * @brief 设置线程结束标志
+     * @param stop true = 结束 false = 正常
+     */
+    void setStop(bool stop);
+
+private:
+    /**
+     * @brief 打印DBUS获取等宽字体和比较字体字符方法获取等宽字体，用来定位DBUS获取字体失败后的问题
+     * @author ut001000 任飞翔
+     */
+    void compareWhiteList();
+    //线程成员变量
+    QThread *m_thread = nullptr;
+    //线程结束标志位
+    bool m_bstop = false;
+};
+/******** Add by ut001000 renfeixiang 2020-06-15:增加 处理等宽字体的类 End***************/
+
+#ifdef DTKCORE_CLASS_DConfigFile
+class LoggerRules : public QObject {
+  Q_OBJECT
+public:
+  explicit LoggerRules(QObject *parent = nullptr);
+  ~LoggerRules();
+
+  void initLoggerRules();
+  inline QString rules() const { return m_rules; }
+  void setRules(const QString &rules);
+
+private:
+  void appendRules(const QString &rules);
+
+private:
+  QString m_rules;
+  Dtk::Core::DConfig *m_config;
+};
+#endif
+
 #endif
