@@ -1,5 +1,5 @@
 // Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -15,8 +15,7 @@
 #include <DKeySequenceEdit>
 #include <DCommandLinkButton>
 #include <DDialogCloseButton>
-#include <DApplicationHelper>
-#include <DPaletteHelper>
+#include <DGuiApplicationHelper>
 #include <DGuiApplicationHelper>
 #include <DWidgetUtil>
 #include <DLog>
@@ -28,6 +27,12 @@
 #include <QApplication>
 #include <QClipboard>
 
+#ifdef QT_DEBUG
+Q_LOGGING_CATEGORY(customcommand,"org.deepin.terminal.customcommand")
+#else
+Q_LOGGING_CATEGORY(customcommand,"org.deepin.terminal.customcommand",QtInfoMsg)
+#endif
+
 CustomCommandOptDlg::CustomCommandOptDlg(CustomCmdOptType type, CustomCommandData *currItemData, QWidget *parent)
     : DAbstractDialog(parent)
     , m_type(type)
@@ -36,6 +41,7 @@ CustomCommandOptDlg::CustomCommandOptDlg(CustomCmdOptType type, CustomCommandDat
     , m_shortCutLineEdit(new DKeySequenceEdit(this))
     , m_bDelOpt(false)
 {
+    qCDebug(customcommand) << "Creating CustomCommandOptDlg, type:" << type;
     /******** Add by ut001000 renfeixiang 2020-08-13:增加 Begin***************/
     Utils::set_Object_Name(this);
     m_nameLineEdit->setObjectName("CustomNameLineEdit");
@@ -44,6 +50,7 @@ CustomCommandOptDlg::CustomCommandOptDlg(CustomCmdOptType type, CustomCommandDat
     /******** Add by ut001000 renfeixiang 2020-08-13:增加 End***************/
     setWindowModality(Qt::WindowModal);
     if (currItemData) {
+        qCDebug(customcommand) << "Branch: currItemData is not null";
         m_currItemData = new CustomCommandData;
         *m_currItemData = *currItemData;
     }
@@ -57,11 +64,14 @@ CustomCommandOptDlg::CustomCommandOptDlg(CustomCmdOptType type, CustomCommandDat
 
 CustomCommandOptDlg::~CustomCommandOptDlg()
 {
+    qCDebug(customcommand) << "Destroying CustomCommandOptDlg";
     if (m_currItemData) {
+        qCDebug(customcommand) << "m_currItemData is not null, deleting";
         delete m_currItemData;
         m_currItemData = nullptr;
     }
     if (m_newAction) {
+        qCDebug(customcommand) << "m_newAction is not null, deleting";
         delete  m_newAction;
         m_newAction = nullptr;
     }
@@ -69,6 +79,7 @@ CustomCommandOptDlg::~CustomCommandOptDlg()
 
 void CustomCommandOptDlg::initUI()
 {
+    qCDebug(customcommand) << "Initializing CustomCommandOptDlg UI";
     QWidget *contentFrame = new QWidget(this);
 
     QVBoxLayout *contentLayout = new QVBoxLayout;
@@ -135,6 +146,7 @@ void CustomCommandOptDlg::initUI()
     addContent(contentFrame);
     //判断是添加操作窗口还是修改操作窗口
     if (CCT_ADD == m_type) {
+        qCInfo(customcommand) << "Setting up Add Command dialog";
         setTitle(tr("Add Command"));
         initCommandFromClipBoardText();
 
@@ -144,6 +156,7 @@ void CustomCommandOptDlg::initUI()
         getMainLayout()->addSpacing(m_iSpaceSizeEighteen);
 #endif
     } else {
+        qCInfo(customcommand) << "Setting up Edit Command dialog";
         setTitle(tr("Edit Command"));
 
         m_deleteCmdWidget = new QWidget(this);
@@ -177,8 +190,10 @@ void CustomCommandOptDlg::initUI()
     addCancelConfirmButtons();
     setCancelBtnText(tr("Cancel", "button"));
     if (CCT_ADD == m_type) {
+        qCDebug(customcommand) << "Setting Add button text";
         setConfirmBtnText(tr("Add", "button"));
     } else {
+        qCDebug(customcommand) << "Setting Save button text";
         setConfirmBtnText(tr("Save", "button"));
     }
     m_lastCmdShortcut = m_shortCutLineEdit->keySequence().toString();
@@ -191,6 +206,7 @@ void CustomCommandOptDlg::initUI()
     // 字体变更时更新布局
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::fontChanged, this, [this](){
         if (isVisible() && layout()) {
+            qCDebug(customcommand) << "isVisible and layout conditions met";
             layout()->invalidate();
             updateGeometry();
             // 根据新界面布局，刷新界面大小
@@ -200,8 +216,10 @@ void CustomCommandOptDlg::initUI()
 
 #else
     if (CCT_ADD == m_type) {
+        qCDebug(customcommand) << "Setting fixed size for Add type";
         setFixedSize(m_iFixedWidth, m_iFixedHeightAddSize);
     } else {
+        qCDebug(customcommand) << "Setting fixed size for Edit type";
         setFixedSize(m_iFixedWidth, m_iFixedHeightEditSize);
     }
 #endif
@@ -209,28 +227,35 @@ void CustomCommandOptDlg::initUI()
 
 inline void CustomCommandOptDlg::slotNameLineEditingFinished()
 {
-    if (m_nameLineEdit->text().isEmpty())
+    qCDebug(customcommand) << "Enter slotNameLineEditingFinished";
+    if (m_nameLineEdit->text().isEmpty()) {
+        qCDebug(customcommand) << "name line edit is empty";
         m_nameLineEdit->lineEdit()->setPlaceholderText(tr("Required"));
+    }
 }
 
 inline void CustomCommandOptDlg::slotCommandLineEditingFinished()
 {
-    if (m_commandLineEdit->text().isEmpty())
+    qCDebug(customcommand) << "Enter slotCommandLineEditingFinished";
+    if (m_commandLineEdit->text().isEmpty()) {
+        qCDebug(customcommand) << "command line edit is empty";
         m_commandLineEdit->lineEdit()->setPlaceholderText(tr("Required"));
+    }
 }
 
 inline void CustomCommandOptDlg::slotShortCutLineEditingFinished(const QKeySequence &sequence)
 {
+    qCDebug(customcommand) << "Enter slotShortCutLineEditingFinished";
     //删除
     if ("Backspace" == sequence.toString()) {
-        qInfo() << "The KeySequenceE is Backspace";
+        qCInfo(customcommand) << "The KeySequenceE is Backspace";
         m_shortCutLineEdit->clear();
         m_lastCmdShortcut = "";
         return;
     }
     // 取消
     if ("Esc" == sequence.toString()) {
-        qInfo() << "The KeySequenceE is Esc";
+        qCInfo(customcommand) << "The KeySequenceE is Esc";
         m_shortCutLineEdit->clear();
         m_shortCutLineEdit->setKeySequence(QKeySequence(m_lastCmdShortcut));
         /***add by ut001121 zhangmeng 20200521 在快捷键编辑框中按下ESC键时退出窗口 修复BUG27554***/
@@ -238,16 +263,18 @@ inline void CustomCommandOptDlg::slotShortCutLineEditingFinished(const QKeySeque
         return;
     }
     QString checkName;
-    if (m_type != CCT_ADD)
+    if (m_type != CCT_ADD) {
+        qCDebug(customcommand) << "type is not CCT_ADD";
         checkName = m_nameLineEdit->text();
+    }
 
     QString reason;
     // 判断快捷键是否冲突
     if (!ShortcutManager::instance()->checkShortcutValid(checkName, sequence.toString(), reason)) {
-        qInfo() << "checkShortcutValid";
+        qCWarning(customcommand) << "Shortcut key conflict";
         // 冲突
         if (sequence.toString() != "Esc") {
-            qInfo() << "sequence != Esc";
+            qCWarning(customcommand) << "The current shortcut key is not Esc! ("<< sequence <<")";
             showShortcutConflictMsgbox(reason);
         }
         m_shortCutLineEdit->clear();
@@ -259,6 +286,7 @@ inline void CustomCommandOptDlg::slotShortCutLineEditingFinished(const QKeySeque
 
 void CustomCommandOptDlg::initUITitle()
 {
+    qCDebug(customcommand) << "Enter initUITitle";
     QVBoxLayout *mainLayout = new QVBoxLayout();
     mainLayout->setSpacing(SPACEHEIGHT);
     mainLayout->setContentsMargins(0, 0, 0, 10);
@@ -292,10 +320,13 @@ void CustomCommandOptDlg::initUITitle()
     // 字色
     DPalette palette = m_titleText->palette();
     QColor color;
-    if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType())
+    if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
+        qCDebug(customcommand) << "Dark theme type";
         color = QColor::fromRgb(192, 198, 212, 255);
-    else
+    } else {
+        qCDebug(customcommand) << "Light theme type";
         color = QColor::fromRgb(0, 26, 46, 255);
+    }
 
     palette.setBrush(QPalette::WindowText, color);
     m_titleText->setPalette(palette);
@@ -324,6 +355,7 @@ void CustomCommandOptDlg::initUITitle()
 
 void CustomCommandOptDlg::initTitleConnections()
 {
+    qCDebug(customcommand) << "Enter initTitleConnections";
     connect(m_closeButton, &DWindowCloseButton::clicked, this, &CustomCommandOptDlg::slotCloseButtonClicked);
     // 字体颜色随主题变化变化
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &CustomCommandOptDlg::slotThemeTypeChanged);
@@ -331,17 +363,22 @@ void CustomCommandOptDlg::initTitleConnections()
 
 inline void CustomCommandOptDlg::slotCloseButtonClicked()
 {
+    // qCDebug(customcommand) << "Enter slotCloseButtonClicked";
     this->close();
 }
 
 inline void CustomCommandOptDlg::slotThemeTypeChanged(DGuiApplicationHelper::ColorType themeType)
 {
+    qCDebug(customcommand) << "Enter slotThemeTypeChanged";
     DPalette palette = m_titleText->palette();
     QColor color;
-    if (DGuiApplicationHelper::DarkType == themeType)
+    if (DGuiApplicationHelper::DarkType == themeType) {
+        qCDebug(customcommand) << "Dark theme type in slotThemeTypeChanged";
         color = QColor::fromRgb(192, 198, 212, 255);
-    else
+    } else {
+        qCDebug(customcommand) << "Light theme type in slotThemeTypeChanged";
         color = QColor::fromRgb(0, 26, 46, 255);
+    }
 
     palette.setBrush(QPalette::WindowText, color);
     m_titleText->setPalette(palette);
@@ -349,10 +386,14 @@ inline void CustomCommandOptDlg::slotThemeTypeChanged(DGuiApplicationHelper::Col
 
 void CustomCommandOptDlg::initCommandFromClipBoardText()
 {
+    qCDebug(customcommand) << "Initializing command from clipboard";
     if (m_commandLineEdit) {
+        qCDebug(customcommand) << "m_commandLineEdit is not null";
         MainWindow *main = Utils::getMainWindow(this);//;getMainWindow();
         if (main != nullptr) {
+            qCDebug(customcommand) << "main window is not null";
             QString clipText = main->selectedText();
+            qCDebug(customcommand) << "Clipboard text:" << clipText;
             m_commandLineEdit->setText(clipText.trimmed());
         }
     }
@@ -360,37 +401,40 @@ void CustomCommandOptDlg::initCommandFromClipBoardText()
 
 QAction *CustomCommandOptDlg::getCurCustomCmd()
 {
+    // qCDebug(customcommand) << "Enter getCurCustomCmd";
     return m_newAction;
 }
 
 bool CustomCommandOptDlg::isDelCurCommand()
 {
+    // qCDebug(customcommand) << "Enter isDelCurCommand";
     return m_bDelOpt;
 }
 
 void CustomCommandOptDlg::slotAddSaveButtonClicked()
 {
+    qCDebug(customcommand) << "Enter slotAddSaveButtonClicked";
     QString strName = m_nameLineEdit->text();
     QString strCommand = m_commandLineEdit->text();
     QKeySequence keytmp = m_shortCutLineEdit->keySequence();
 
     strName = strName.trimmed();//空格的名称是无效的，剔除名称前后的空格
     if (strName.isEmpty()) {
-        qInfo() << "Name is empty";
+        qCWarning(customcommand) << "The name of the user-defined command is empty!";
         m_nameLineEdit->showAlertMessage(tr("Please enter a name"), m_nameLineEdit->parentWidget());
         return;
     }
 
     /***add begin by ut001121 zhangmeng 20200615 限制名称字符长度 修复BUG31286***/
     if (strName.length() > MAX_NAME_LEN) {
-        qInfo() << "The name should be no more than 32 characters";
+        qCWarning(customcommand) << "The name should be no more than 32 characters";
         m_nameLineEdit->showAlertMessage(QObject::tr("The name should be no more than 32 characters"), m_nameLineEdit->parentWidget());
         return;
     }
     /***add end by ut001121***/
     QString strCommandtemp = strCommand.trimmed();//空格的命令是无效的
     if (strCommandtemp.isEmpty()) {
-        qInfo() << "Command is empty";
+        qCWarning(customcommand) << "The custom command is empty";
         m_commandLineEdit->showAlertMessage(tr("Please enter a command"), m_commandLineEdit->parentWidget());
         return;
     }
@@ -405,20 +449,20 @@ void CustomCommandOptDlg::slotAddSaveButtonClicked()
     QAction *existAction = nullptr;
     int icount = 0;
     if (CCT_MODIFY == m_type) {
-        qInfo() << "It is the modify type of custom command operation";
+        qCInfo(customcommand) << "It is the modify type of custom command operation";
         if (m_bRefreshCheck) {
-            qInfo() << "CustomCommand was refreshed";
+            qCInfo(customcommand) << "CustomCommand was refreshed";
             QAction *refreshExitAction = nullptr;
             refreshExitAction = ShortcutManager::instance()->checkActionIsExist(*m_newAction);
             if (refreshExitAction) {
-                qInfo() << "CustomCommand already exists";
+                qCWarning(customcommand) << "The custom command already exists";
                 accept();
                 return;
             }
         }
 
         if (strName == m_currItemData->m_cmdName && strCommand == m_currItemData->m_cmdText && keytmp == QKeySequence(m_currItemData->m_cmdShortcut)) {
-            qInfo() << "CustomCommand don't need to save again";
+            qCInfo(customcommand) << "The custom command don't need to save again.";
             accept();
             return;
         }
@@ -426,25 +470,30 @@ void CustomCommandOptDlg::slotAddSaveButtonClicked()
         existAction = ShortcutManager::instance()->checkActionIsExistForModify(*m_newAction);
 
         if (strName != m_currItemData->m_cmdName) {
-            qInfo() << "CustomCommand is changed";
+            qCInfo(customcommand) << "Custom commands have been changed.";
             QList<QAction *> &customCommandActionList = ShortcutManager::instance()->getCustomCommandActionList();
             for (int i = 0; i < customCommandActionList.size(); i++) {
+                // qCDebug(customcommand) << "Loop iteration:" << i;
                 QAction *curAction = customCommandActionList[i];
                 QString strCmdName = curAction->text();
-                if (strCmdName == strName)
+                if (strCmdName == strName) {
+                    // qCDebug(customcommand) << "found matching command name";
                     icount++;
+                }
             }
         }
     } else {
+        qCInfo(customcommand) << "It is the add type of custom command operation";
         existAction = ShortcutManager::instance()->checkActionIsExist(*m_newAction);
     }
 
     if (nullptr != existAction || icount) {
-        qInfo() << "The name already exists";
+        qCInfo(customcommand) << "The name already exists";
         QString strFistLine = tr("The name already exists,");
         QString strSecondeLine = tr("please input another one.");
         Utils::showSameNameDialog(this, strFistLine, strSecondeLine);
     } else {
+        qCDebug(customcommand) << "accepting dialog";
         accept();
     }
     /************************ Mod by m000743 sunchengxi 2020-04-21:自定义命令修改的异常问题 End  ************************/
@@ -452,17 +501,23 @@ void CustomCommandOptDlg::slotAddSaveButtonClicked()
 
 bool CustomCommandOptDlg::checkSequence(const QKeySequence &sequence)
 {
+    qCDebug(customcommand) << "Enter checkSequence";
     QString checkName = m_nameLineEdit->text();
 
-    if (sequence.toString().isEmpty())
+    if (sequence.toString().isEmpty()) {
+        qCDebug(customcommand) << "sequence is empty";
         return true;
+    }
 
     QString reason;
     // 判断快捷键是否冲突
     if (!ShortcutManager::instance()->checkShortcutValid(checkName, sequence.toString(), reason)) {
+        qCDebug(customcommand) << "shortcut key conflict in checkSequence";
         // 冲突
-        if (sequence.toString() != "Esc")
+        if (sequence.toString() != "Esc") {
+            qCDebug(customcommand) << "sequence is not Esc in checkSequence";
             showShortcutConflictMsgbox(reason);
+        }
 
         m_shortCutLineEdit->clear();
         m_shortCutLineEdit->setKeySequence(QKeySequence(m_lastCmdShortcut));
@@ -478,17 +533,21 @@ bool CustomCommandOptDlg::checkSequence(const QKeySequence &sequence)
 
 void CustomCommandOptDlg::setModelIndex(const QModelIndex &mi)
 {
+    // qCDebug(customcommand) << "Enter setModelIndex";
     modelIndex = mi;
 }
 
 void CustomCommandOptDlg::slotDelCurCustomCommand()
 {
+    // qCDebug(customcommand) << "Enter slotDelCurCustomCommand";
+    qCInfo(customcommand) << "Deleting current custom command";
     m_bDelOpt = true;
     reject();
 }
 
 void CustomCommandOptDlg::addCancelConfirmButtons()
 {
+    // qCDebug(customcommand) << "Enter addCancelConfirmButtons";
     QHBoxLayout *buttonsLayout = new QHBoxLayout();
     buttonsLayout->setSpacing(9);
     buttonsLayout->setContentsMargins(10, 0, 10, 0);
@@ -512,11 +571,11 @@ void CustomCommandOptDlg::addCancelConfirmButtons()
     setTabOrder(m_confirmBtn, m_closeButton);//设置右上角关闭按钮的tab键控制顺序
 
     m_verticalLine = new DVerticalLine(this);
-    DPalette pa = DApplicationHelper::instance()->palette(m_verticalLine);
+    DPalette pa = DPaletteHelper::instance()->palette(m_verticalLine);
     QColor splitColor = pa.color(DPalette::ItemBackground);
-    pa.setBrush(DPalette::Background, splitColor);
+    pa.setBrush(DPalette::Window, splitColor);
     m_verticalLine->setPalette(pa);
-    m_verticalLine->setBackgroundRole(QPalette::Background);
+    m_verticalLine->setBackgroundRole(QPalette::Window);
     m_verticalLine->setAutoFillBackground(true);
     m_verticalLine->setFixedSize(3, 28);
 
@@ -540,18 +599,21 @@ void CustomCommandOptDlg::addCancelConfirmButtons()
 
 inline void CustomCommandOptDlg::slotCancelBtnClicked()
 {
+    // qCDebug(customcommand) << "Enter slotCancelBtnClicked";
     m_confirmResultCode = QDialog::Rejected;
     reject();
 }
 
 inline void CustomCommandOptDlg::slotConfirmBtnClicked()
 {
+    // qCDebug(customcommand) << "Enter slotConfirmBtnClicked";
     m_confirmResultCode = QDialog::Accepted;
     emit confirmBtnClicked();
 }
 
 inline void CustomCommandOptDlg::slotShortCutLineEditFinished()
 {
+    // qCDebug(customcommand) << "Enter slotShortCutLineEditFinished";
     /******** Add by nt001000 renfeixiang 2020-05-14:修改快捷框输入后，添加（m_confirmBtn）按钮高亮问题,将光标从添加按钮取消，设置到快捷框上 Begin***************/
     m_shortCutLineEdit->setFocus();
     /******** Add by nt001000 renfeixiang 2020-05-14:修改快捷框输入后，添加（m_confirmBtn）按钮高亮问题,将光标从添加按钮取消，设置到快捷框上 End***************/
@@ -559,11 +621,13 @@ inline void CustomCommandOptDlg::slotShortCutLineEditFinished()
 
 QVBoxLayout *CustomCommandOptDlg::getMainLayout()
 {
+    // qCDebug(customcommand) << "Enter getMainLayout";
     return m_mainLayout;
 }
 
 QDialog::DialogCode CustomCommandOptDlg::getConfirmResult()
 {
+    // qCDebug(customcommand) << "Enter getConfirmResult";
     return m_confirmResultCode;
 }
 
@@ -582,38 +646,49 @@ QDialog::DialogCode CustomCommandOptDlg::getConfirmResult()
 
 void CustomCommandOptDlg::setTitle(const QString &title)
 {
-    if (nullptr != m_titleText)
+    // qCDebug(customcommand) << "Enter setTitle";
+    if (nullptr != m_titleText) {
+        qCDebug(customcommand) << "m_titleText is not null";
         m_titleText->setText(title);
+    }
 }
 
 QLayout *CustomCommandOptDlg::getContentLayout()
 {
+    // qCDebug(customcommand) << "Enter getContentLayout";
     return m_contentLayout;
 }
 
 void CustomCommandOptDlg::setCancelBtnText(const QString &strCancel)
 {
+    // qCDebug(customcommand) << "Enter setCancelBtnText";
     m_cancelBtn->setText(strCancel);
     Utils::setSpaceInWord(m_cancelBtn);
 }
 
 void CustomCommandOptDlg::setConfirmBtnText(const QString &strConfirm)
 {
+    // qCDebug(customcommand) << "Enter setConfirmBtnText";
     m_confirmBtn->setText(strConfirm);
     Utils::setSpaceInWord(m_confirmBtn);
 }
 
 void CustomCommandOptDlg::showShortcutConflictMsgbox(QString txt)
 {
+    qCDebug(customcommand) << "Enter showShortcutConflictMsgbox";
     /******** Modify by ut000610 daizhengwen 2020-05-27: 出现提示和快捷键显示不一致的问题 bug#28507****************/
     // fix#bug 37399
     for (QString key : ShortcutManager::instance()->m_mapReplaceText.keys()) {
-        if (txt.contains(key))
+        // qCDebug(customcommand) << "Loop iteration for key:" << key;
+        if (txt.contains(key)) {
+            // qCDebug(customcommand) << "txt contains key";
             txt.replace(key, ShortcutManager::instance()->m_mapReplaceText[key]);
+        }
     }
     /********************* Modify by ut000610 daizhengwen End ************************/
     // 若没有弹窗，初始化
     if (nullptr == m_shortcutConflictDialog) {
+        qCDebug(customcommand) << "m_shortcutConflictDialog is null, initializing";
         m_shortcutConflictDialog = new DDialog(this);
         m_shortcutConflictDialog->setObjectName("CustomShortcutConflictDialog");//Add by ut001000 renfeixiang 2020-08-13
         /******** Modify by nt001000 renfeixiang 2020-05-29:修改 因为弹框改为非模态之后，快捷框冲突选中快捷框功能移动这 Begin***************/
@@ -630,6 +705,7 @@ void CustomCommandOptDlg::showShortcutConflictMsgbox(QString txt)
 
 inline void CustomCommandOptDlg::slotShortcutConflictDialogFinished()
 {
+    // qCDebug(customcommand) << "Enter slotShortcutConflictDialogFinished";
     m_shortcutConflictDialog->hide();
     /******** Add by nt001000 renfeixiang 2020-05-14:快捷框输入已经存在的快捷后，快捷框依然是选中状态 Begin***************/
     QTimer::singleShot(30, this, &CustomCommandOptDlg::slotSetShortCutLineEditFocus);
@@ -638,6 +714,7 @@ inline void CustomCommandOptDlg::slotShortcutConflictDialogFinished()
 
 inline void CustomCommandOptDlg::slotSetShortCutLineEditFocus()
 {
+    // qCDebug(customcommand) << "Enter slotSetShortCutLineEditFocus";
     m_shortCutLineEdit->setFocus();
 }
 
@@ -647,27 +724,33 @@ inline void CustomCommandOptDlg::slotSetShortCutLineEditFocus()
  */
 void CustomCommandOptDlg::updateSizeMode()
 {
+    // qCDebug(customcommand) << "Enter updateSizeMode";
 #ifdef DTKWIDGET_CLASS_DSizeMode
     if (DGuiApplicationHelper::isCompactMode()) {
+        qCDebug(customcommand) << "compact mode";
         m_titleBar->setFixedHeight(WIN_TITLE_BAR_HEIGHT_COMPACT);
         m_logoIcon->setFixedSize(QSize(ICONSIZE_40_COMPACT, ICONSIZE_40_COMPACT));
         m_closeButton->setIconSize(QSize(ICONSIZE_40_COMPACT, ICONSIZE_40_COMPACT));
         m_verticalLine->setFixedSize(VERTICAL_WIDTH_COMPACT, VERTICAL_HEIGHT_COMPACT);
         if (m_deleteCmdWidget) {
+            qCDebug(customcommand) << "m_deleteCmdWidget is not null in compact mode";
             m_deleteCmdWidget->setFixedHeight(m_iFixedHeightCompact);
         }
 
     } else {
+        qCDebug(customcommand) << "normal mode";
         m_titleBar->setFixedHeight(WIN_TITLE_BAR_HEIGHT);
         m_logoIcon->setFixedSize(QSize(ICONSIZE_50, ICONSIZE_50));
         m_closeButton->setIconSize(QSize(ICONSIZE_50, ICONSIZE_50));
         m_verticalLine->setFixedSize(VERTICAL_WIDTH, VERTICAL_HEIGHT);
         if (m_deleteCmdWidget) {
+            qCDebug(customcommand) << "m_deleteCmdWidget is not null in normal mode";
             m_deleteCmdWidget->setFixedHeight(m_iFixedHeight);
         }
     }
 
     if (layout()) {
+        qCDebug(customcommand) << "layout is not null";
         layout()->invalidate();
     }
 
@@ -679,6 +762,7 @@ void CustomCommandOptDlg::updateSizeMode()
 
 void CustomCommandOptDlg::addContent(QWidget *content)
 {
+    // qCDebug(customcommand) << "Enter addContent";
     Q_ASSERT(nullptr != m_contentLayout);
 
     m_contentLayout->addWidget(content);
@@ -686,7 +770,9 @@ void CustomCommandOptDlg::addContent(QWidget *content)
 
 void CustomCommandOptDlg::setIconPixmap(const QPixmap &iconPixmap)
 {
+    // qCDebug(customcommand) << "Enter setIconPixmap";
     if (nullptr != m_logoIcon) {
+        qCDebug(customcommand) << "m_logoIcon is not null";
         m_logoIcon->setVisible(true);
         m_logoIcon->setPixmap(iconPixmap);
     }
@@ -694,6 +780,7 @@ void CustomCommandOptDlg::setIconPixmap(const QPixmap &iconPixmap)
 
 void CustomCommandOptDlg::closeEvent(QCloseEvent *event)
 {
+    // qCDebug(customcommand) << "Enter closeEvent";
     Q_UNUSED(event)
 
     done(-1);
@@ -703,20 +790,24 @@ void CustomCommandOptDlg::closeEvent(QCloseEvent *event)
 
 void CustomCommandOptDlg::slotRefreshData(QString oldCmdName, QString newCmdName)
 {
+    // qCDebug(customcommand) << "Enter slotRefreshData";
     if (CCT_ADD == m_type) {
-        qInfo() << "Currently is the add operation interface";
+        qCWarning(customcommand) << "Currently is the add operation interface";
         return;
     }
     //不进行刷新操作
-    if (oldCmdName.isEmpty() && newCmdName.isEmpty())
+    if (oldCmdName.isEmpty() && newCmdName.isEmpty()) {
+        qCDebug(customcommand) << "both oldCmdName and newCmdName are empty";
         return;
+    }
 
     //当前的自定义命令的名称 不是被修改的自定义名称时，不进行刷新操作
     if (m_currItemData->m_cmdName != oldCmdName) {
+        qCDebug(customcommand) << "current command name doesn't match oldCmdName";
         return;
     }
     m_bRefreshCheck = true;
-    qInfo() << "slotRefreshData---" <<  m_nameLineEdit->text();
+    qCInfo(customcommand) << "Refresh custom command data.Curren command name is " <<  m_nameLineEdit->text();
 
     QAction *currAction = new QAction(ShortcutManager::instance());
     currAction->setText(newCmdName);
@@ -724,15 +815,18 @@ void CustomCommandOptDlg::slotRefreshData(QString oldCmdName, QString newCmdName
     existAction = ShortcutManager::instance()->checkActionIsExist(*currAction);
     //根据 newCmdName 查找自定义命令
     if (nullptr == existAction) {
+        qCDebug(customcommand) << "existAction is null";
         //不存在，则认为当前自定义命令在其他编辑窗口中删除了，如果打开了删除确认界面，则关闭删除确认界面。关闭当前编辑窗口
         delete currAction;
         if (m_dlgDelete && m_dlgDelete->isVisible()) {
+            qCDebug(customcommand) << "m_dlgDelete is visible, closing";
             m_dlgDelete->close();
             m_dlgDelete = nullptr;
         }
 
         close();
     } else {
+        qCDebug(customcommand) << "existAction is not null, updating data";
         //当前自定义命令在其他窗口修改，则更新数据
         delete currAction;
         m_nameLineEdit->setText(existAction->text());
@@ -745,5 +839,6 @@ void CustomCommandOptDlg::slotRefreshData(QString oldCmdName, QString newCmdName
 
 void CustomCommandOptDlg::closeRefreshDataConnection()
 {
+    // qCDebug(customcommand) << "Enter closeRefreshDataConnection";
     disconnect(Service::instance(), &Service::refreshCommandPanel, this, &CustomCommandOptDlg::slotRefreshData);
 }
