@@ -1,5 +1,5 @@
 // Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -11,8 +11,7 @@
 #include "utils.h"
 #include "mainwindow.h"
 
-#include <DApplicationHelper>
-#include <DPaletteHelper>
+#include <DGuiApplicationHelper>
 #include <DMessageBox>
 
 #include <QAction>
@@ -21,16 +20,21 @@
 #include <QCoreApplication>
 #include <QTimer>
 #include <QDebug>
+#include <QLoggingCategory>
+Q_DECLARE_LOGGING_CATEGORY(customcommand)
 
 CustomCommandSearchRstPanel::CustomCommandSearchRstPanel(QWidget *parent)
     : CommonPanel(parent)
 {
+    qCDebug(customcommand) << "Creating CustomCommandSearchRstPanel";
     Utils::set_Object_Name(this);
     initUI();
+    qCDebug(customcommand) << "CustomCommandSearchRstPanel created";
 }
 
 void CustomCommandSearchRstPanel::initUI()
 {
+    qCDebug(customcommand) << "Initializing CustomCommandSearchRstPanel UI";
     setBackgroundRole(QPalette::Base);
     setAutoFillBackground(true);
 
@@ -47,10 +51,13 @@ void CustomCommandSearchRstPanel::initUI()
     // 字体颜色随主题变化变化
     DPalette palette = m_label->palette();
     QColor color;
-    if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType())
+    if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
+        qCDebug(customcommand) << "Dark theme type";
         color = QColor::fromRgb(192, 198, 212, 102);
-    else
+    } else {
+        qCDebug(customcommand) << "Light theme type";
         color = QColor::fromRgb(85, 85, 85, 102);
+    }
 
     palette.setBrush(QPalette::Text, color);
     m_label->setPalette(palette);
@@ -64,13 +71,13 @@ void CustomCommandSearchRstPanel::initUI()
     // 搜索框居中显示
     hlayout->addWidget(m_label, 0, Qt::AlignCenter);
     hlayout->setSpacing(0);
-    hlayout->setMargin(0);
+    hlayout->setContentsMargins(0, 0, 0, 0);
 
     QVBoxLayout *vlayout = new QVBoxLayout();
     vlayout->addSpacing(10);
     vlayout->addLayout(hlayout);
     vlayout->addWidget(m_cmdListWidget);
-    vlayout->setMargin(0);
+    vlayout->setContentsMargins(0, 0, 0, 0);
     vlayout->setSpacing(10);
     setLayout(vlayout);
 
@@ -86,12 +93,16 @@ void CustomCommandSearchRstPanel::initUI()
 
 inline void CustomCommandSearchRstPanel::handleThemeTypeChanged(DGuiApplicationHelper::ColorType themeType)
 {
+    // qCDebug(customcommand) << "Enter handleThemeTypeChanged";
     DPalette palette = m_label->palette();
     QColor color;
-    if (DGuiApplicationHelper::DarkType == themeType)
+    if (DGuiApplicationHelper::DarkType == themeType) {
+        // qCDebug(customcommand) << "Dark theme type in handleThemeTypeChanged";
         color = QColor::fromRgb(192, 198, 212, 102);
-    else
+    } else {
+        // qCDebug(customcommand) << "Light theme type in handleThemeTypeChanged";
         color = QColor::fromRgb(85, 85, 85, 102);
+    }
 
     palette.setBrush(QPalette::Text, color);
     m_label->setPalette(palette);
@@ -99,59 +110,74 @@ inline void CustomCommandSearchRstPanel::handleThemeTypeChanged(DGuiApplicationH
 
 inline void CustomCommandSearchRstPanel::handleIconButtonFocusOut(Qt::FocusReason type)
 {
+    // qCDebug(customcommand) << "Enter handleIconButtonFocusOut";
     // 焦点切出，没值的时候
     if (Qt::TabFocusReason == type && 0 == m_cmdListWidget->count()) {
+        qCDebug(customcommand) << "TabFocusReason and cmdListWidget count is 0";
         // tab 进入 +
         QKeyEvent keyPress(QEvent::KeyPress, Qt::Key_Tab, Qt::MetaModifier);
         QApplication::sendEvent(Utils::getMainWindow(this), &keyPress);
-        qInfo() << "search panel focus to '+'";
+        qCInfo(customcommand) << "search panel focus to '+'";
     }
 }
 
 inline void CustomCommandSearchRstPanel::handleListViewFocusOut(Qt::FocusReason type)
 {
+    // qCDebug(customcommand) << "Enter handleListViewFocusOut";
     Q_UNUSED(type);
     if (Qt::TabFocusReason == type) {
+        qCDebug(customcommand) << "TabFocusReason";
         // tab 进入 +
         QKeyEvent keyPress(QEvent::KeyPress, Qt::Key_Tab, Qt::MetaModifier);
         QApplication::sendEvent(Utils::getMainWindow(this), &keyPress);
-        qInfo() << "search panel focus on '+'";
+        qCInfo(customcommand) << "search panel focus on '+'";
         m_cmdListWidget->clearIndex();
     } else if (Qt::BacktabFocusReason == type || Qt::NoFocusReason == type) {
+        qCDebug(customcommand) << "BacktabFocusReason or NoFocusReason";
         // shift + tab 返回 返回键               // 列表为空，也返回到返回键上
         m_rebackButton->setFocus();
         m_cmdListWidget->clearIndex();
-        qInfo() << "search panel type" << type;
+        qCInfo(customcommand) << "search panel type (" << type << ")";
     }
 }
 
 void CustomCommandSearchRstPanel::setSearchFilter(const QString &filter)
 {
+    qCDebug(customcommand) << "Setting search filter:" << filter;
     m_strFilter = filter;
     QString showText = Utils::getElidedText(m_label->font(), filter, ITEMMAXWIDTH, Qt::ElideMiddle);
     m_label->setText(QString("%1：%2").arg(tr("Search"), showText));
+    qCDebug(customcommand) << "Search filter set to:" << showText;
 }
 
 void CustomCommandSearchRstPanel::refreshData()
 {
+    qCDebug(customcommand) << "Refreshing data with current filter:" << m_strFilter;
     ShortcutManager::instance()->fillCommandListData(m_cmdListWidget, m_strFilter);
+    qCDebug(customcommand) << "Data refreshed, item count:" << m_cmdListWidget->count();
 }
 
 void CustomCommandSearchRstPanel::refreshData(const QString &strFilter)
 {
+    qCDebug(customcommand) << "Refreshing data with new filter:" << strFilter;
     setSearchFilter(strFilter);
     ShortcutManager::instance()->fillCommandListData(m_cmdListWidget, strFilter);
+    qCDebug(customcommand) << "Data refreshed with new filter, item count:" << m_cmdListWidget->count();
 }
 
 void CustomCommandSearchRstPanel::doCustomCommand(const QString &strKey)
 {
-    qInfo() << "doCustomCommand,key=" << strKey;
+    qCInfo(customcommand) << "Executing custom command with key:" << strKey;
     QAction *item = ShortcutManager::instance()->findActionByKey(strKey);
     QString strCommand = item ? item->data().toString() : "";
-    if (!strCommand.endsWith('\n'))
+    if (!strCommand.endsWith('\n')) {
+        qCDebug(customcommand) << "Command does not end with newline, appending one";
         strCommand.append('\n');
+    }
 
+    qCInfo(customcommand) << "Executing command:" << strCommand;
     emit handleCustomCurCommand(strCommand);
     emit focusOut();
+    qCDebug(customcommand) << "Command execution complete";
 }
 
