@@ -24,7 +24,6 @@
 
 #include <DSuggestButton>
 #include <DVerticalLine>
-#include <DPaletteHelper>
 
 GroupConfigOptDlg::GroupConfigOptDlg(const QString &groupName, QWidget *parent)
     : DAbstractDialog(false, parent),
@@ -49,7 +48,7 @@ GroupConfigOptDlg::GroupConfigOptDlg(const QString &groupName, QWidget *parent)
     // 字色
     DPalette palette = m_titleLabel->palette();
     QColor color;
-    if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType())
+    if (DApplicationHelper::DarkType == DApplicationHelper::instance()->themeType())
         color = QColor::fromRgb(192, 198, 212, 255);
     else
         color = QColor::fromRgb(0, 26, 46, 255);
