@@ -1,5 +1,5 @@
 // Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -9,22 +9,26 @@
 #include "iconbutton.h"
 #include "mainwindow.h"
 
-#include <DApplicationHelper>
-#include <DPaletteHelper>
+#include <DGuiApplicationHelper>
 
 #include <QKeyEvent>
 #include <QApplication>
 #include <QCoreApplication>
 #include <QDebug>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(remotemanage)
 
 RemoteManagementSearchPanel::RemoteManagementSearchPanel(QWidget *parent) : CommonPanel(parent)
 {
+    qCDebug(remotemanage) << "RemoteManagementSearchPanel constructor";
     Utils::set_Object_Name(this);
     initUI();
 }
 
 void RemoteManagementSearchPanel::initUI()
 {
+    qCDebug(remotemanage) << "Enter initUI";
     this->setBackgroundRole(QPalette::Base);
     this->setAutoFillBackground(true);
 
@@ -42,10 +46,13 @@ void RemoteManagementSearchPanel::initUI()
     // 字体颜色随主题变化而变化
     DPalette palette = m_label->palette();
     QColor color;
-    if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType())
+    if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
+        qCDebug(remotemanage) << "using dark theme color";
         color = QColor::fromRgb(192, 198, 212, 102);
-    else
+    } else {
+        qCDebug(remotemanage) << "using light theme color";
         color = QColor::fromRgb(85, 85, 85, 102);
+    }
 
     palette.setBrush(QPalette::Text, color);
     m_label->setPalette(palette);
@@ -55,13 +62,13 @@ void RemoteManagementSearchPanel::initUI()
     hlayout->addWidget(m_rebackButton);
     hlayout->addWidget(m_label, 0, Qt::AlignCenter);
     hlayout->setSpacing(0);
-    hlayout->setMargin(0);
+    hlayout->setContentsMargins(0, 0, 0, 0);
 
     QVBoxLayout *vlayout = new QVBoxLayout();
     vlayout->addSpacing(SPACEHEIGHT);
     vlayout->addLayout(hlayout);
     vlayout->addWidget(m_listWidget);
-    vlayout->setMargin(0);
+    vlayout->setContentsMargins(0, 0, 0, 0);
     vlayout->setSpacing(SPACEHEIGHT);
     setLayout(vlayout);
 
@@ -75,32 +82,40 @@ void RemoteManagementSearchPanel::initUI()
     connect(m_listWidget, &ListView::focusOut, this, &RemoteManagementSearchPanel::handleListViewFocusOut);
     // 字体颜色随主题变化变化
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &RemoteManagementSearchPanel::handleThemeTypeChanged);
+    qCDebug(remotemanage) << "Exit initUI";
 }
 
 inline void RemoteManagementSearchPanel::handleListViewFocusOut(Qt::FocusReason type)
 {
+    qCDebug(remotemanage) << "Enter RemoteManagementSearchPanel::handleListViewFocusOut";
     if (Qt::TabFocusReason == type) {
+        qCDebug(remotemanage) << "tab focus reason";
         // tab 进入 +
         QKeyEvent keyPress(QEvent::KeyPress, Qt::Key_Tab, Qt::MetaModifier);
         QApplication::sendEvent(Utils::getMainWindow(this), &keyPress);
-        qInfo() << "search panel focus on '+'";
+        qCInfo(remotemanage) << "search panel focus on '+'";
         m_listWidget->clearIndex();
     } else if (Qt::BacktabFocusReason == type || Qt::NoFocusReason == type) {
+        qCDebug(remotemanage) << "backtab or no focus reason";
         // shift + tab 返回 返回键               // 列表为空，也返回到返回键上
         m_rebackButton->setFocus();
         m_listWidget->clearIndex();
-        qInfo() << "search panel type" << type;
+        qCInfo(remotemanage) << "search panel type" << type;
     }
 }
 
 inline void RemoteManagementSearchPanel::handleThemeTypeChanged(DGuiApplicationHelper::ColorType themeType)
 {
+    qCDebug(remotemanage) << "Enter RemoteManagementSearchPanel::handleThemeTypeChanged";
     DPalette palette = m_label->palette();
     QColor color;
-    if (DGuiApplicationHelper::DarkType == themeType)
+    if (DGuiApplicationHelper::DarkType == themeType) {
+        qCDebug(remotemanage) << "changing to dark theme";
         color = QColor::fromRgb(192, 198, 212, 102);
-    else
+    } else {
+        qCDebug(remotemanage) << "changing to light theme";
         color = QColor::fromRgb(85, 85, 85, 102);
+    }
 
     palette.setBrush(QPalette::Text, color);
     m_label->setPalette(palette);
@@ -108,62 +123,75 @@ inline void RemoteManagementSearchPanel::handleThemeTypeChanged(DGuiApplicationH
 
 void RemoteManagementSearchPanel::refreshDataByGroupAndFilter(const QString &strGroup, const QString &strFilter)
 {
+    qCDebug(remotemanage) << "Enter refreshDataByGroupAndFilter, group:" << strGroup << "filter:" << strFilter;
     setSearchFilter(strFilter);
     m_isGroupOrNot = true;
     m_strGroupName = strGroup;
     m_strFilter = strFilter;
     m_listWidget->clearData();
     ServerConfigManager::instance()->refreshServerList(ServerConfigManager::PanelType_Search, m_listWidget, strFilter, strGroup);
+    qCDebug(remotemanage) << "Exit refreshDataByGroupAndFilter";
 }
 
 void RemoteManagementSearchPanel::refreshDataByFilter(const QString &strFilter)
 {
+    qCDebug(remotemanage) << "Enter refreshDataByFilter, filter:" << strFilter;
     setSearchFilter(strFilter);
     m_isGroupOrNot = false;
     m_strFilter = strFilter;
     m_listWidget->clearData();
     ServerConfigManager::instance()->refreshServerList(ServerConfigManager::PanelType_Search, m_listWidget, strFilter);
+    qCDebug(remotemanage) << "Exit refreshDataByFilter";
 }
 
 void RemoteManagementSearchPanel::onItemClicked(const QString &key)
 {
+    qCDebug(remotemanage) << "onItemClicked, key:" << key;
     // 获取远程信息
     ServerConfig *remote = ServerConfigManager::instance()->getServerConfig(key);
-    if (nullptr != remote)
+    if (nullptr != remote) {
+        qCDebug(remotemanage) << "remote config found, emitting doConnectServer";
         emit doConnectServer(remote);
-    else
-        qInfo() << "can't connect to remote" << key;
-
+    } else {
+        qCInfo(remotemanage) << "can't connect to remote" << key;
+    }
 }
 
 void RemoteManagementSearchPanel::onFocusOutList(Qt::FocusReason type)
 {
+    // // qCDebug(remotemanage) << "Enter RemoteManagementSearchPanel::onFocusOutList";
     // 焦点切出，没值的时候
     if (Qt::TabFocusReason == type && 0 == m_listWidget->count()) {
+        qCDebug(remotemanage) << "tab focus reason and list is empty";
         // tab 进入 +
         QKeyEvent keyPress(QEvent::KeyPress, Qt::Key_Tab, Qt::MetaModifier);
         QApplication::sendEvent(Utils::getMainWindow(this), &keyPress);
-        qInfo() << "search panel focus to '+'";
+        qCInfo(remotemanage) << "search panel focus to '+'";
     }
+    qCDebug(remotemanage) << "Exit onRefreshList";
 }
 
 void RemoteManagementSearchPanel::onRefreshList()
 {
+    qCDebug(remotemanage) << "Enter onRefreshList";
     // 判断是否显示
     if (m_isShow) {
+        qCDebug(remotemanage) << "panel is shown";
         if (m_isGroupOrNot) {
+            qCDebug(remotemanage) << "refreshing group search list";
             // 刷新分组下搜索列表
             refreshDataByGroupAndFilter(m_strGroupName, m_strFilter);
         } else {
+            qCDebug(remotemanage) << "refreshing global search list";
             // 刷新搜索列表
             refreshDataByFilter(m_strFilter);
         }
     }
 }
 
-
 void RemoteManagementSearchPanel::clearAllFocus()
 {
+    qCDebug(remotemanage) << "Enter RemoteManagementSearchPanel::clearAllFocus";
     m_rebackButton->clearFocus();
     m_listWidget->clearFocus();
     m_label->clearFocus();
@@ -171,40 +199,49 @@ void RemoteManagementSearchPanel::clearAllFocus()
 
 void RemoteManagementSearchPanel::setFocusBack(const QString &strGroup, bool isFocusOn, int prevIndex)
 {
-    qInfo() << "RemoteManagementSearchPanel return from RemoteManagementGroup.";
+    qCInfo(remotemanage) << "RemoteManagementSearchPanel return from RemoteManagementGroup.";
     // 返回前判断之前是否要有焦点
     if (isFocusOn) {
+        qCDebug(remotemanage) << "focus is required";
         // 要有焦点
         // 找到分组的新位置
         int index = m_listWidget->indexFromString(strGroup, ItemFuncType_Group);
         if (index < 0) {
+            qCDebug(remotemanage) << "group not found, getting next index";
             // 小于0代表没找到 获取下一个
             index = m_listWidget->getNextIndex(prevIndex);
         }
 
         if (index >= 0) {
+            qCDebug(remotemanage) << "setting focus to list index:" << index;
             // 找得到, 设置焦点
             m_listWidget->setCurrentIndex(index);
         } else {
+            qCDebug(remotemanage) << "setting focus to reback button";
             // 没找到焦点设置到添加按钮
             m_rebackButton->setFocus();
         }
     }
     // 不要焦点
     else {
+        qCDebug(remotemanage) << "focus is not required";
         MainWindow *w = Utils::getMainWindow(this);
-        if(w)
+        if(w) {
+            qCDebug(remotemanage) << "setting focus to current page";
             w->focusCurrentPage();
+        }
     }
 }
 
 int RemoteManagementSearchPanel::getListIndex()
 {
+    // qCDebug(remotemanage) << "Enter RemoteManagementSearchPanel::getListIndex";
     return m_listWidget->currentIndex();
 }
 
 void RemoteManagementSearchPanel::setSearchFilter(const QString &filter)
 {
+    qCDebug(remotemanage) << "setSearchFilter, filter:" << filter;
     m_strFilter = filter;
     QString showText = filter;
     showText = Utils::getElidedText(m_label->font(), showText, ITEMMAXWIDTH, Qt::ElideMiddle);
