@@ -1,5 +1,5 @@
 // Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -10,10 +10,13 @@
 
 #include <QDebug>
 #include <QTextCodec>
+#include <QLoggingCategory>
 
 #undef signals
 #include <libsecret/secret.h>
 
+Q_DECLARE_LOGGING_CATEGORY(remotemanage)
+
 // 密码回调
 struct PasswordReBack {
     QString key;
@@ -25,15 +28,19 @@ ServerConfigManager *ServerConfigManager::m_instance = nullptr;
 
 ServerConfigManager::ServerConfigManager(QObject *parent) : QObject(parent)
 {
+    qCDebug(remotemanage) << "ServerConfigManager constructor";
     Utils::set_Object_Name(this);
     QSettings::registerFormat("conf", SettingIO::readIniFunc, SettingIO::writeIniFunc);
     // 查找结果,写入map
     connect(this, &ServerConfigManager::lookupSerceats, this, &ServerConfigManager::onLookupFinish);
+    qCDebug(remotemanage) << "ServerConfigManager initialization complete";
 }
 
 void ServerConfigManager::settServerConfig(USettings &commandsSettings, const QString &strGroupName, ServerConfig *config)
 {
+    qDebug() << "Enter ServerConfigManager::settServerConfig with group:" << strGroupName;
     commandsSettings.beginGroup(strGroupName);
+    qDebug() << "Setting server configuration values";
     commandsSettings.setValue("userName", config->m_userName);
     commandsSettings.setValue("address", config->m_address);
     commandsSettings.setValue("port", config->m_port);
@@ -47,6 +54,7 @@ void ServerConfigManager::settServerConfig(USettings &commandsSettings, const QS
     commandsSettings.setValue("Backspace", config->m_backspaceKey);
     commandsSettings.setValue("Del", config->m_deleteKey);
     commandsSettings.setValue("PrivateKey", config->m_privateKey);
+    qDebug() << "Ending group settings";
     commandsSettings.endGroup();
 }
 
@@ -67,18 +75,21 @@ void ServerConfigManager::fillServerList(ListView *listview, const QString &grou
 
 void ServerConfigManager::fillManagePanel(ListView *listview)
 {
-    qInfo() << "ServerConfigManager fill data to manage panel.";
+    qCInfo(remotemanage) << "ServerConfigManager fill data to manage panel.";
     listview->clearData();
     for (QString key : m_serverConfigs.keys()) {
         // key有效
         // 先后添加组和项对顺序没影响
         // 此处先后顺序只是符合界面显示顺序，方便阅读 判断key 是否为""，只是为了严格判断是否是没有分组的项
         if (!key.isEmpty() && !key.isNull()) {
+            // qCDebug(remotemanage) << "adding group item:" << key;
             // 添加组
             listview->addItem(ItemFuncType_Group, key);
         } else if (key == "") {
+            // qCDebug(remotemanage) << "adding server items for empty group";
             // 添加项
             for (ServerConfig *item : m_serverConfigs[key]) {
+                // qDebug() << "Adding server item:" << item->m_serverName;
                 listview->addItem(ItemFuncType_Item, item->m_serverName, QString("%1@%2").arg(item->m_userName).arg(item->m_address));
             }
         }
@@ -90,58 +101,72 @@ void ServerConfigManager::fillManagePanel(ListView *listview)
 
 void ServerConfigManager::fillSearchPanel(ListView *listview, const QString &filter, const QString &group)
 {
-    qInfo() << "ServerConfigManager fill data to search panel.";
+    qCInfo(remotemanage) << "ServerConfigManager fill data to search panel.";
     listview->clearData();
     // 判断是否是组内搜索
     if (group.isEmpty() || group.isNull()) {
+        qCDebug(remotemanage) << "global search";
         // 没有组，全局搜索
         for (QString key : m_serverConfigs.keys()) {
             // key有效
             if (!key.isEmpty() && !key.isNull()) {
                 // 组匹配
                 if (key.contains(filter, Qt::CaseSensitivity::CaseInsensitive)) {
+                    // qCDebug(remotemanage) << "group matches filter, adding group:" << key;
                     // 添加组
                     listview->addItem(ItemFuncType_Group, key);
                 }
             }
             // 组内匹配
+            // qDebug() << "Checking items in group:" << key;
             for (ServerConfig *item : m_serverConfigs[key]) {
                 if (item->m_serverName.contains(filter, Qt::CaseSensitivity::CaseInsensitive)
                         || item->m_userName.contains(filter, Qt::CaseSensitivity::CaseInsensitive)
-                        || item->m_address.contains(filter, Qt::CaseSensitivity::CaseInsensitive))
+                        || item->m_address.contains(filter, Qt::CaseSensitivity::CaseInsensitive)) {
+                    // qCDebug(remotemanage) << "server item matches filter, adding item:" << item->m_serverName;
                     // 添加项
                     listview->addItem(ItemFuncType_Item, item->m_serverName, QString("%1@%2").arg(item->m_userName).arg(item->m_address));
+                }
             }
         }
     } else {
+        qCDebug(remotemanage) << "group search for group:" << group;
         // 组内搜索
         for (QString key : m_serverConfigs.keys()) {
             // 找到分组
-            if (key != group)
+            if (key != group) {
                 continue;
+            }
+            // qDebug() << "Found matching group, checking items";
             // 组内匹配
             for (ServerConfig *item : m_serverConfigs[key]) {
                 if (item->m_serverName.contains(filter, Qt::CaseSensitivity::CaseInsensitive)
                         || item->m_userName.contains(filter, Qt::CaseSensitivity::CaseInsensitive)
-                        || item->m_address.contains(filter, Qt::CaseSensitivity::CaseInsensitive))
+                        || item->m_address.contains(filter, Qt::CaseSensitivity::CaseInsensitive)) {
+                    // qCDebug(remotemanage) << "server item matches filter in group, adding item:" << item->m_serverName;
                     // 添加项
                     listview->addItem(ItemFuncType_Item, item->m_serverName, QString("%1@%2").arg(item->m_userName).arg(item->m_address));
+                }
             }
         }
     }
-
 }
 
 void ServerConfigManager::fillGroupPanel(ListView *listview, const QString &group)
 {
+    // qDebug() << "Enter ServerConfigManager::fillGroupPanel with group:" << group;
     listview->clearData();
     // 遍历
+    qDebug() << "Searching for group in" << m_serverConfigs.keys().size() << "groups";
     for (QString key : m_serverConfigs.keys()) {
         // 找到分组
-        if (key != group)
+        if (key != group) {
             continue;
+        }
+        // qCDebug(remotemanage) << "found matching group, adding items" << group;
         // 组内匹配
         for (ServerConfig *item : m_serverConfigs[key]) {
+            // qDebug() << "Adding item:" << item->m_serverName;
             // 添加项
             listview->addItem(ItemFuncType_Item, item->m_serverName, QString("%1@%2").arg(item->m_userName).arg(item->m_address));
         }
@@ -150,52 +175,74 @@ void ServerConfigManager::fillGroupPanel(ListView *listview, const QString &grou
 
 ServerConfigManager *ServerConfigManager::instance()
 {
-    if (nullptr == m_instance)
+    // qCDebug(remotemanage) << "ServerConfigManager instance requested";
+    if (nullptr == m_instance) {
+        qCDebug(remotemanage) << "Creating new ServerConfigManager instance";
         m_instance = new ServerConfigManager();
+    }
     return m_instance;
 }
 
 void ServerConfigManager::initServerConfig()
 {
+    qCDebug(remotemanage) << "Enter initServerConfig";
     bool isConvertData =  false;
+    qDebug() << "Clearing existing server configs";
     m_serverConfigs.clear();
     //---------------------------------------------------------------------------//
+    qDebug() << "Getting server config base path";
     QDir serverConfigBasePath(QStandardPaths::writableLocation(QStandardPaths::AppConfigLocation));
-    if (!serverConfigBasePath.exists())
+    if (!serverConfigBasePath.exists()) {
+        qCDebug(remotemanage) << "server config base path does not exist";
         return;
+    }
 
     QString serverConfigFilePath(serverConfigBasePath.filePath("server-config.conf"));
-    qInfo() << "load Server Config: " << serverConfigFilePath;
-    if (!QFile::exists(serverConfigFilePath))
+    qCInfo(remotemanage) << "load Server Config: " << serverConfigFilePath;
+    if (!QFile::exists(serverConfigFilePath)) {
+        qCDebug(remotemanage) << "server config file does not exist";
         return;
+    }
 
     /***modify begin by ut001121 zhangmeng 20201221 修复BUG58747 远程管理和自定义命令名称中带/重启后会出现命令丢失***/
     /* del
     QSettings serversSettings(serverConfigFilePath, QSettings::CustomFormat1);
     serversSettings.setIniCodec(QTextCodec::codecForName("UTF-8"));*/
     /* add */
+    qDebug() << "Creating USettings for server config";
     USettings serversSettings(serverConfigFilePath);
     /***modify end by ut001121***/
 
+    qDebug() << "Getting server groups from settings";
     QStringList serverGroups = serversSettings.childGroups();
+    qDebug() << "Found" << serverGroups.size() << "server groups";
     for (QString &serverName : serverGroups) {
+        // qDebug() << "Processing server group:" << serverName;
         serversSettings.beginGroup(serverName);
         QStringList strList = serverName.split("@");
         ServerConfig *pServerConfig = new ServerConfig();
         if (strList.count() < 3) {
-            qInfo() << __FUNCTION__ << serverName << strList.count() << "error";
+            qCWarning(remotemanage)  << "An unknoew error exists on the current server(" << serverName <<  ")";
             continue;
         }
         // 新版数据的读取方式
         // 读取方式优化，原本保存到groupName的值，改为保存到value里
         // 若配置文件没有包含userName、address、port，则读取groupName的，反之读取key-value
-        if(!serversSettings.contains("userName"))
+        // qDebug() << "Checking and setting userName, address, port from config";
+        if(!serversSettings.contains("userName")) {
+            // qCDebug(remotemanage) << "userName not found, using from group name";
             serversSettings.setValue("userName", strList.at(0));
-        if(!serversSettings.contains("address"))
+        }
+        if(!serversSettings.contains("address")) {
+            // qCDebug(remotemanage) << "address not found, using from group name";
             serversSettings.setValue("address", strList.at(1));
-        if(!serversSettings.contains("port"))
+        }
+        if(!serversSettings.contains("port")) {
+            // qCDebug(remotemanage) << "port not found, using from group name";
             serversSettings.setValue("port", strList.at(2));
+        }
 
+        // qDebug() << "Reading server configuration values";
         pServerConfig->m_userName = serversSettings.value("userName").toString();
         pServerConfig->m_address = serversSettings.value("address").toString();
         pServerConfig->m_port = serversSettings.value("port").toString();
@@ -208,21 +255,28 @@ void ServerConfigManager::initServerConfig()
         pServerConfig->m_backspaceKey = serversSettings.value("Backspace").toString();
         pServerConfig->m_deleteKey = serversSettings.value("Del").toString();
         pServerConfig->m_privateKey = serversSettings.value("PrivateKey").toString();
+        // qDebug() << "Ending group settings for server:" << pServerConfig->m_serverName;
         serversSettings.endGroup();
 
         // 兼容旧版本的操作 1) 旧版配置文件需要重写 2) 密码明文需要重写
-        if (OLD_VERTIONCOUNT == strList.count() || !pServerConfig->m_password.isEmpty())
+        if (OLD_VERTIONCOUNT == strList.count() || !pServerConfig->m_password.isEmpty()) {
+            // qCDebug(remotemanage) << "need to convert data for compatibility";
             isConvertData = true;
+        }
 
         // 旧终端的唯一值
         QString strKey =
             QString("%1@%2@%3@%4").arg(strList.at(0)).arg(strList.at(1)).arg(strList.at(2)).arg(pServerConfig->m_serverName);
+        // qDebug() << "Checking for duplicate config with key:" << strKey;
         if (m_remoteConfigs.contains(strKey)) {
+            // qCDebug(remotemanage) << "duplicate config found for key:" << strKey;
             if (OLD_VERTIONCOUNT == strList.count()) {
+                // qCDebug(remotemanage) << "current is old version, deleting";
                 // 现在是旧的
                 delete pServerConfig;
                 break;
             } else {
+                // qCDebug(remotemanage) << "current is new version, removing old";
                 // 现在是新的
                 ServerConfig *config = m_remoteConfigs[strKey];
                 m_remoteConfigs.remove(strKey);
@@ -231,48 +285,60 @@ void ServerConfigManager::initServerConfig()
 
         }
 
+        // qDebug() << "Inserting server config into remote configs";
         m_remoteConfigs.insert(strKey, pServerConfig);
 
     }
 
+    qDebug() << "Processing server names to avoid duplicates";
     for (ServerConfig *pServerConfig : m_remoteConfigs) {
         // 避免出现ServerName相同的情况相同情况下给他加(i)
         if (m_remoteName.contains(pServerConfig->m_serverName)) {
+            // qCDebug(remotemanage) << "duplicate server name found, adding suffix";
             int i = ++m_remoteName[pServerConfig->m_serverName];
             QString strServerName = QString("%1(%2)").arg(pServerConfig->m_serverName).arg(QString::number(i));
             pServerConfig->m_serverName = strServerName;
         } else {
+            // qCDebug(remotemanage) << "unique server name, adding to map";
             m_remoteName[pServerConfig->m_serverName] = 1;
         }
     }
 
-
+    // qDebug() << "Processing password retrieval for servers";
     // 新数据写入map
     for (ServerConfig *config : m_remoteConfigs) {
         // 没有密码的情况都要去DBus中获取一下
         if (config->m_password.isEmpty()) {
+            // qCDebug(remotemanage) << "password is empty, getting secrets from DBus";
             remoteGetSecreats(config->m_userName, config->m_address, config->m_port, config->m_serverName);
             ++m_lookupCount;
         }
         // 将数据写入map
+        // qDebug() << "Adding config to server configs map for group:" << config->m_group;
         m_serverConfigs[config->m_group].append(config);
     }
 
-
+    qDebug() << "Checking if config rewrite is needed";
     // 若rewrite为true删除原数据,将内存的数据写入原文件
     m_rewriteConfig = (SettingIO::rewrite || isConvertData);
     // 没有需要查找的数据,直接判断是否重写配置文件
-    if (m_rewriteConfig && 0 == m_lookupCount)
+    if (m_rewriteConfig && 0 == m_lookupCount) {
+        qCDebug(remotemanage) << "rewrite config and no lookup needed, converting data";
         ConvertData();
+    }
 
+    qCDebug(remotemanage) << "Exit initServerConfig";
     return;
 }
 
 void ServerConfigManager::saveServerConfig(ServerConfig *config)
 {
+    qCDebug(remotemanage) << "Enter saveServerConfig, server:" << config->m_serverName;
     QDir customCommandBasePath(QStandardPaths::writableLocation(QStandardPaths::AppConfigLocation));
-    if (!customCommandBasePath.exists())
+    if (!customCommandBasePath.exists()) {
+        qCDebug(remotemanage) << "config path does not exist, creating directory";
         customCommandBasePath.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppConfigLocation));
+    }
 
     QString customCommandConfigFilePath(customCommandBasePath.filePath("server-config.conf"));
     /***modify begin by ut001121 zhangmeng 20201221 修复BUG58747 远程管理和自定义命令名称中带/重启后会出现命令丢失***/
@@ -289,8 +355,9 @@ void ServerConfigManager::saveServerConfig(ServerConfig *config)
     // 添加密码
     remoteStoreSecreats(config);
 
-    qInfo() << "append success!" << config->m_group << config->m_serverName;
+    qCInfo(remotemanage) << "The server configuration is added successfully.The Config group: " << config->m_group  << ".The Server name:"<< config->m_serverName;
 
+    qCDebug(remotemanage) << "Exit saveServerConfig";
 }
 
 void ServerConfigManager::delServerGroupConfig(const QString &key)
@@ -311,14 +378,18 @@ void ServerConfigManager::delServerGroupConfig(const QString &key)
 
 void ServerConfigManager::delServerConfig(ServerConfig *config)
 {
+    qCDebug(remotemanage) << "Enter delServerConfig, server:" << config->m_serverName;
     // 防止重复删除
     if (nullptr == config) {
+        qCDebug(remotemanage) << "config is null, returning";
         return;
     }
     // 读写配置文件
     QDir customCommandBasePath(QStandardPaths::writableLocation(QStandardPaths::AppConfigLocation));
-    if (!customCommandBasePath.exists())
+    if (!customCommandBasePath.exists()) {
+        qCDebug(remotemanage) << "config path does not exist, creating directory";
         customCommandBasePath.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppConfigLocation));
+    }
 
     QString customCommandConfigFilePath(customCommandBasePath.filePath("server-config.conf"));
     /***modify begin by ut001121 zhangmeng 20201221 修复BUG58747 远程管理和自定义命令名称中带/重启后会出现命令丢失***/
@@ -343,6 +414,7 @@ void ServerConfigManager::delServerConfig(ServerConfig *config)
     m_serverConfigs[config->m_group].removeOne(config);
     // 判断组成员
     if (0 == m_serverConfigs[config->m_group].count()) {
+        qCDebug(remotemanage) << "group has no members, removing group:" << config->m_group;
         // 若组内无成员
         m_serverConfigs.remove(config->m_group);
     }
@@ -352,6 +424,7 @@ void ServerConfigManager::delServerConfig(ServerConfig *config)
 
 void ServerConfigManager::modifyServerConfig(ServerConfig *newConfig, ServerConfig *oldConfig)
 {
+    qCDebug(remotemanage) << "Enter modifyServerConfig, old:" << oldConfig->m_serverName << "new:" << newConfig->m_serverName;
     SyncData(oldConfig->m_serverName, newConfig);
     // 刷新已有数据
     delServerConfig(oldConfig);
@@ -360,19 +433,24 @@ void ServerConfigManager::modifyServerConfig(ServerConfig *newConfig, ServerConf
 
 QMap<QString, QList<ServerConfig *>> &ServerConfigManager::getServerConfigs()
 {
+    // qDebug() << "Enter ServerConfigManager::getServerConfigs";
     return m_serverConfigs;
 }
 
 void ServerConfigManager::refreshServerList(PanelType type, ListView *listview, const QString &filter, const QString &group)
 {
+    // qDebug() << "Enter ServerConfigManager::refreshServerList";
     switch (type) {
     case PanelType_Manage:
+        qCDebug(remotemanage) << "refreshing manage panel";
         fillManagePanel(listview);
         break;
     case PanelType_Group:
+        qCDebug(remotemanage) << "refreshing group panel";
         fillGroupPanel(listview, group);
         break;
     case PanelType_Search:
+        qCDebug(remotemanage) << "refreshing search panel";
         fillSearchPanel(listview, filter, group);
         break;
     case PanelType_Serverlist:
@@ -383,13 +461,15 @@ void ServerConfigManager::refreshServerList(PanelType type, ListView *listview,
 
 void ServerConfigManager::setModifyDialog(QString key, ServerConfigOptDlg *dlg)
 {
+    // qDebug() << "Enter ServerConfigManager::setModifyDialog";
     // 添加编辑弹窗
     m_serverConfigDialogMap[key].append(dlg);
-    qInfo() << "show edit dialog" << key << m_serverConfigDialogMap[key].count() << dlg;
+    qCInfo(remotemanage) << "show edit dialog" << key << m_serverConfigDialogMap[key].count() << dlg;
 }
 
 void ServerConfigManager::removeDialog(ServerConfigOptDlg *dlg)
 {
+    // qDebug() << "Enter ServerConfigManager::removeDialog";
     QString key;
     ServerConfigOptDlg *removeOne = nullptr;
     // 1.查找dlg指针
@@ -398,6 +478,7 @@ void ServerConfigManager::removeDialog(ServerConfigOptDlg *dlg)
         //遍历列表
         for (ServerConfigOptDlg *dlgItem : item.value()) {
             if (dlgItem == dlg) {
+                // qCDebug(remotemanage) << "found dialog to remove";
                 key = item.key();
                 removeOne = dlgItem;
             }
@@ -405,17 +486,17 @@ void ServerConfigManager::removeDialog(ServerConfigOptDlg *dlg)
     }
     // 2.删除数据
     if (nullptr != removeOne) {
-        qInfo() << "delete dialog from remote name : " << key;
+        qCInfo(remotemanage) << "delete dialog from remote name : " << key;
         m_serverConfigDialogMap[key].removeOne(removeOne);
     }
 
     if (0 == m_serverConfigDialogMap[key].count()) {
-        qInfo() << "remote dialog is 0, remove remote name : " << key;
+        qCInfo(remotemanage) << "remote dialog is 0, remove remote name : " << key;
         m_serverConfigDialogMap.remove(key);
     }
 
     if (nullptr != removeOne) {
-        qInfo() << "delete remote dialog" << removeOne;
+        qCInfo(remotemanage) << "delete remote dialog" << removeOne;
         removeOne->deleteLater();
     }
     removeOne = nullptr;
@@ -423,7 +504,7 @@ void ServerConfigManager::removeDialog(ServerConfigOptDlg *dlg)
 
 void ServerConfigManager::SyncData(QString key, ServerConfig *newConfig)
 {
-    qInfo() << key << newConfig->m_serverName;
+    qCInfo(remotemanage) <<"Sync Data! Key: " << key << ";Server Name:" << newConfig->m_serverName;
     //前提是key唯一
     // serverName被修改
     if (key != newConfig->m_serverName) {
@@ -444,17 +525,17 @@ void ServerConfigManager::SyncData(QString key, ServerConfig *newConfig)
 
 void ServerConfigManager::closeAllDialog(QString key)
 {
-    qInfo() << __FUNCTION__ << "remote name : " <<  key << m_serverConfigDialogMap.count();
+    qCInfo(remotemanage) << "Close ALL Dialogs for the remote server! Remote name : " <<  key ;
     // 判读此时这个key是否存在
     if (!m_serverConfigDialogMap.contains(key)) {
         // 不存在退出
-        qInfo() << __FUNCTION__ << "not contains " <<  key;
+        qCWarning(remotemanage) << "The current remote(" << key <<") server does not exist!";
         return;
     }
 
     for (auto &item : m_serverConfigDialogMap[key]) {
         if (item != nullptr) {
-            qInfo() << __FUNCTION__ << "reject : " <<  item;
+            qCInfo(remotemanage) << "Reject the current remote window(" <<  item << ")!";
             // reject就会把当前的窗口删除
             item->reject();
         }
@@ -463,31 +544,36 @@ void ServerConfigManager::closeAllDialog(QString key)
 
 int ServerConfigManager::getServerCount(const QString &strGroupName)
 {
+    qCInfo(remotemanage) << "Enter getServerCount, group name:" << strGroupName;
     if (strGroupName.isEmpty() || strGroupName.isNull()) {
-        qInfo() << "enter error group name:" << strGroupName << "! please confirm again!";
+        qCWarning(remotemanage) << "enter error group name:" << strGroupName << "! please confirm again!";
         return -1;
     }
     if (m_serverConfigs.contains(strGroupName)) {
+        qCInfo(remotemanage) << "contain group name:" << strGroupName << "count:" << m_serverConfigs[strGroupName].count();
         // 返回组个数
         return m_serverConfigs[strGroupName].count();
     }
+    qCWarning(remotemanage) << "not contain group name, return 0";
     // 不包含
     return 0;
 }
 
 ServerConfig *ServerConfigManager::getServerConfig(const QString &key)
 {
+    qCInfo(remotemanage) << "Enter getServerConfig, key:" << key;
     // 遍历查找
     for (const QString &groupName : m_serverConfigs.keys()) {
         for (ServerConfig *item : m_serverConfigs[groupName]) {
             if (key == item->m_serverName) {
+                qCInfo(remotemanage) << "find remote key : " << key;
                 // 找到返回值
                 return item;
             }
         }
     }
     // 没找到返回空
-    qInfo() << "can't find remote key : " << key;
+    qCWarning(remotemanage) << "can't find remote key : " << key;
     return nullptr;
 }
 
@@ -499,12 +585,14 @@ ServerConfig *ServerConfigManager::getServerConfig(const QString &key)
 *******************************************************************************/
 static void on_password_lookup(GObject *source, GAsyncResult *result, gpointer unused)
 {
+    qCInfo(remotemanage) << "Enter on_password_lookup";
     Q_UNUSED(source);
     GError *error = NULL;
 
     PasswordReBack *reback = static_cast<PasswordReBack *>(unused);
     Q_ASSERT(reback);
     if (NULL == unused) {
+        qCInfo(remotemanage) << "unused is NULL, return";
         emit reback->manager->lookupSerceats(reback->key, "");
         return;
     }
@@ -513,16 +601,17 @@ static void on_password_lookup(GObject *source, GAsyncResult *result, gpointer u
 
     if (error != NULL) {
         /* ... handle the failure here */
-        qInfo() << error->message;
+        qCWarning(remotemanage) << "Failed to get password! error msg:" << error->message;
         g_error_free(error);
         emit reback->manager->lookupSerceats(reback->key, "");
     } else if (password == NULL) {
         /* password will be null, if no matching password found */
         // 密码回调
-        qInfo() << "password is Null server name : " << reback->key;
+        qCInfo(remotemanage) << "password is Null server name : " << reback->key;
         emit reback->manager->lookupSerceats(reback->key, "");
 
     } else {
+        qCInfo(remotemanage) << "password is not Null server name : " << reback->key;
         /* ... do something with the password */
         // 将密码写入
         emit reback->manager->lookupSerceats(reback->key, QString(password));
@@ -534,6 +623,7 @@ static void on_password_lookup(GObject *source, GAsyncResult *result, gpointer u
 
 void ServerConfigManager::remoteGetSecreats(const QString &userName, const QString &address, const QString &port, const QString &key)
 {
+    qCInfo(remotemanage) << "Enter remoteGetSecreats";
     QString strSchemaName = QString("com.deepin.terminal.password.%1.%2.%3").arg(userName).arg(address).arg(port);
     const SecretSchema *scheme =
         secret_schema_new(strSchemaName.toUtf8().data(), SECRET_SCHEMA_NONE, "number", SECRET_SCHEMA_ATTRIBUTE_INTEGER, "string", SECRET_SCHEMA_ATTRIBUTE_STRING, "even", SECRET_SCHEMA_ATTRIBUTE_BOOLEAN, NULL);
@@ -558,6 +648,7 @@ void ServerConfigManager::remoteGetSecreats(const QString &userName, const QStri
 *******************************************************************************/
 static void on_password_stored(GObject *source, GAsyncResult *result, gpointer unused)
 {
+    qCInfo(remotemanage) << "Enter on_password_stored";
     Q_UNUSED(source);
     Q_UNUSED(unused);
     GError *error = NULL;
@@ -565,15 +656,17 @@ static void on_password_stored(GObject *source, GAsyncResult *result, gpointer u
     secret_password_store_finish(result, &error);
     if (error != NULL) {
         /* ... handle the failure here */
-        qInfo() << error->message;
+        qCWarning(remotemanage) << "Failed to store password! error msg:" << error->message;
         g_error_free(error);
     } else {
+        qCInfo(remotemanage) << "store password success";
         /* ... do something now that the password has been stored */
     }
 }
 
 void ServerConfigManager::remoteStoreSecreats(ServerConfig *config)
 {
+    qCInfo(remotemanage) << "Enter remoteStoreSecreats";
     QString strLabel = QString("com.deepin.terminal.password.%1.%2").arg(config->m_userName).arg(config->m_address);
     QString strSchemaName = QString("com.deepin.terminal.password.%1.%2.%3").arg(config->m_userName).arg(config->m_address).arg(config->m_port);
     const SecretSchema *scheme =
@@ -595,6 +688,7 @@ void ServerConfigManager::remoteStoreSecreats(ServerConfig *config)
 *******************************************************************************/
 static void on_password_cleared(GObject *source, GAsyncResult *result, gpointer unused)
 {
+    qCInfo(remotemanage) << "Enter on_password_cleared";
     Q_UNUSED(source);
     Q_UNUSED(unused);
     GError *error = NULL;
@@ -603,17 +697,18 @@ static void on_password_cleared(GObject *source, GAsyncResult *result, gpointer
 
     if (error != NULL) {
         /* ... handle the failure here */
-        qInfo() << __FUNCTION__ << error->message;
+        qCWarning(remotemanage) << "Failed to clear password! error msg:" << error->message;
         g_error_free(error);
 
     } else {
         /* removed will be TRUE if a password was removed */
-        qInfo() << "remove result " << removed;
+        qCInfo(remotemanage) << "remove result " << removed;
     }
 }
 
 void ServerConfigManager::remoteClearSecreats(const QString &userName, const QString &address, const QString &port)
 {
+    qCInfo(remotemanage) << "Enter remoteClearSecreats";
     QString strSchemaName = QString("com.deepin.terminal.password.%1.%2.%3").arg(userName).arg(address).arg(port);
     const SecretSchema *scheme =
         secret_schema_new(strSchemaName.toUtf8().data(), SECRET_SCHEMA_NONE, "number", SECRET_SCHEMA_ATTRIBUTE_INTEGER, "string", SECRET_SCHEMA_ATTRIBUTE_STRING, "even", SECRET_SCHEMA_ATTRIBUTE_BOOLEAN, NULL);
@@ -624,6 +719,7 @@ void ServerConfigManager::remoteClearSecreats(const QString &userName, const QSt
 
 void ServerConfigManager::ConvertData()
 {
+    qCInfo(remotemanage) << "Enter ConvertData";
     // 读写配置文件
     QDir customCommandBasePath(QStandardPaths::writableLocation(QStandardPaths::AppConfigLocation));
     if (!customCommandBasePath.exists())
@@ -655,6 +751,7 @@ void ServerConfigManager::ConvertData()
 
 void ServerConfigManager::onLookupFinish(const QString &key, const QString &password)
 {
+    qCInfo(remotemanage) << "Enter onLookupFinish";
     --m_lookupCount;
     // 遍历
     for (QList<ServerConfig *> &list : m_serverConfigs) {
@@ -668,6 +765,7 @@ void ServerConfigManager::onLookupFinish(const QString &key, const QString &pass
     }
     // 判断所有密码是否都读取完成 且 是否需要重写
     if (0 == m_lookupCount && m_rewriteConfig) {
+        qCInfo(remotemanage) << "all password is read, rewrite config";
         m_rewriteConfig = false;
         // 重写数据
         ConvertData();
@@ -677,4 +775,5 @@ void ServerConfigManager::onLookupFinish(const QString &key, const QString &pass
 
 ServerConfigManager::~ServerConfigManager()
 {
+    qCInfo(remotemanage) << "Enter ServerConfigManager destructor";
 }
