@@ -1,4 +1,5 @@
-// SPDX-FileCopyrightText: 2019 ~ 2023 UnionTech Software Technology Co., Ltd.
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -66,10 +67,6 @@ public:
      * @return
      */
     bool cursorBlink() const;
-    /**
-     * @brief enableSetCursorPosition
-     * @return
-     */
     bool enableSetCursorPosition() const;
     /**
      * @brief 设置界面获取背景模糊属性
@@ -120,6 +117,8 @@ public:
      * @return
      */
     bool ScrollWheelZoom();
+    // 是否允许 Ctrl+Alt+滚轮 调整透明度
+    bool OpacityCtrlAltScrollWheel();
 //    void reload();
     /**
      * @brief 标签标题
@@ -212,6 +211,7 @@ public:
      * @author 朱科伟
      * @return
      */
+    bool enableControlFlow(void);
     bool disableControlFlow(void);
     // 是否启用debuginfod：设置或取消DEBUGINFOD_URLS环境变量
     bool enableDebuginfod();
@@ -225,6 +225,19 @@ public:
      */
     int historySize() const;
 
+    void setFontSize(const int size);
+    void setFontName(const QString font);
+    void setOpacity(const int opacity);
+    void setConsoleColorScheme(const QString scheme);
+    void setCursorShape(const int shape);
+    void setCursorBlink(const bool blink);
+    void setConsoleShell(const QString shellName);
+
+    //选择主题，false:选择主题未确定，读写缓存； true:选择主题已确定，读写settings
+    //这里默认true是为了：启动时读取settings的值
+    bool bSwitchTheme           = true;
+    //选择主题未确定的缓存
+    QMap<QString, QString> switchThemeMap;
     //主题名称
     QString themeStr            = "";
     //内置主题名称
@@ -306,13 +319,13 @@ signals:
     void opacityChanged(qreal opacity);
     void cursorShapeChanged(int shape);
     void cursorBlinkChanged(bool blink);
-    void enableSetCursorPosition(bool enable);
     void backgroundBlurChanged(bool enabled);
     void pressingScrollChanged(bool enabled);
     void OutputScrollChanged(bool enabled);
     void fontSizeChanged(int fontSize);
     void fontChanged(QString fontName);
     void wordCharactersChanged(QString wordCharacters);
+    void enableSetCursorPosition(bool enable);
     void historySizeChanged(int historySize);
 
     // 设置中的标签标题格式变化
