@@ -1,5 +1,5 @@
 // Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -8,7 +8,7 @@
 
 // dtk
 #include <DIconButton>
-#include <DApplicationHelper>
+#include <DGuiApplicationHelper>
 #include <DFloatingWidget>
 #include <DPalette>
 #include <DSearchEdit>
