@@ -1,5 +1,5 @@
 // Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -9,12 +9,14 @@
 #include "define.h"
 #include "termproperties.h"
 #include "pagesearchbar.h"
+#include "mainwindow.h"
 #include "utils.h"
 #include "tabrenamedlg.h"
 
 #include <DSplitter>
 
 #include <QWidget>
+#include <QTextCodec>
 
 DWIDGET_USE_NAMESPACE
 
